##  Report Metadata Review
This section outlines items required for the reporting metadata.
### Screenshots
  * Screenshots should be exactly 1280px x 800px and should not exceed a size of 1 MB.
  * Multiple screenshots should show a clear progression throughout the report.
  * Screenshots should always display the entire browser window without any cropping.


### Thumbnails
Thumbnails should be exactly 1280px x 800px and should not exceed a size of 400KB.
### Description
  * The report should include a concise summary detailing its use cases, functionalities, used fact sheet types, and tags.
  * The description should specify if the report modifies existing data (for example, by using a mutation).


### Requirements
The requirement of the following for the report:
  * Configured data fields
  * Specific tags
  * Data required for the report to work
